% Renumber the nodes and the cells using an optimal numbering of the finite
% element nodes. 
% 
% function [fens, gcells]=renum_mesh(fens, gcells, method)
% 
% fens, gcells = arrays of finite element nodes and geometric cells
% method =  either 'symrcm' or 'symamd' (optional argument, default
%           'symrcm') 
%     
function [fens, gcells]=renum_mesh(fens, gcells, method)
    if (~exist('method','var'))
        method ='symrcm';
    end

    conns = gcells_to_conns(gcells);
    A=conn_to_sparse(conns);
    p= 1:size(A,1);
     
    
    if (strcmp(method,'symrcm'))
        % Reverse Cuthill-McKee
        p=symrcm(A);
    elseif (strcmp(method,'symamd'))
        p=symamd(A);
    else
        eval(['p=' method '(A);']);
    end
    

    ip=(1:length(p));
    ip(p)=(1:length(p));

    for C=1:length(gcells)
        conn=get(gcells(C),'conn');
        gcells(C)=set(gcells(C),'conn',ip(conn));
    end

    ofens=fens;
    for C=1:length(fens)
        fens(C)=set(ofens(p(C)),'id',C);
    end
end


